Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(776)

Unified Diff: chrome/browser/chromeos/system/automatic_reboot_manager_observer.h

Issue 727363002: Fire notifications when reboot is requested, not scheduled (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@managed_cros
Patch Set: Add missing run_loop.Run(); Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/system/automatic_reboot_manager_observer.h
diff --git a/chrome/browser/chromeos/system/automatic_reboot_manager_observer.h b/chrome/browser/chromeos/system/automatic_reboot_manager_observer.h
index 67c1b50c7ba6db64af1c5c5f7228d36b89434e92..0a750bc994c97c2a35e604db19ee58a4e7a17f83 100644
--- a/chrome/browser/chromeos/system/automatic_reboot_manager_observer.h
+++ b/chrome/browser/chromeos/system/automatic_reboot_manager_observer.h
@@ -16,8 +16,8 @@ class AutomaticRebootManagerObserver {
REBOOT_REASON_PERIODIC,
};
- // Invoked when a reboot is scheduled.
- virtual void OnRebootScheduled(Reason reason) = 0;
+ // Invoked when a reboot is requested.
+ virtual void OnRebootRequested(Reason reason) = 0;
// Invoked before the automatic reboot manager is destroyed.
virtual void WillDestroyAutomaticRebootManager() = 0;

Powered by Google App Engine
This is Rietveld 408576698